Learn R Programming

automerge (version 0.3.0)

am_get_actor: Get the actor ID of a document

Description

Returns the actor ID of an Automerge document as a raw vector. The actor ID uniquely identifies the editing session that created changes in the document.

Usage

am_get_actor(doc)

Value

A raw vector containing the actor ID bytes

Arguments

doc

An Automerge document

Details

For a hex string representation, use am_get_actor_hex().

Examples

Run this code
doc <- am_create()
actor <- am_get_actor(doc)
actor

# Use am_get_actor_hex() for display
actor_hex <- am_get_actor_hex(doc)
cat("Actor ID:", actor_hex, "\n")

am_close(doc)

Run the code above in your browser using DataLab