Learn R Programming

automerge (version 0.3.0)

am_list: Create an Automerge list

Description

Creates an R list with explicit Automerge list type. Use this when you need to create an empty list or force list type interpretation.

Usage

am_list(...)

Value

A list with class am_list_type

Arguments

...

Elements to include in the list

Examples

Run this code
# Empty list (avoids ambiguity)
am_list()

# Populated list
am_list("a", "b", "c")

Run the code above in your browser using DataLab