Learn R Programming

automerge (version 0.3.0)

am_change_message: Get the commit message of a change

Description

Returns the commit message attached to a change, or NULL if no message was provided when the change was committed.

Usage

am_change_message(change)

Value

A character string containing the commit message, or NULL

Arguments

change

An am_change object (from am_get_changes(), am_get_changes(), or am_change_from_bytes())

Examples

Run this code
doc <- am_create()
am_put(doc, AM_ROOT, "key", "value")
am_commit(doc, "Add key")

history <- am_get_changes(doc)
am_change_message(history[[1]])  # "Add key"

am_close(doc)

Run the code above in your browser using DataLab