powered by
Returns the number of operations contained in the change. Useful for estimating the size of changes before syncing or storing them.
am_change_size(change)
An integer (or double for very large values exceeding R's 32-bit integer range)
An am_change object (from am_get_changes(), am_get_changes(), or am_change_from_bytes())
am_change
am_get_changes()
am_change_from_bytes()
doc <- am_create() am_put(doc, AM_ROOT, "x", 1) am_put(doc, AM_ROOT, "y", 2) am_commit(doc, "Add keys") history <- am_get_changes(doc) am_change_size(history[[1]]) # 2 am_close(doc)
Run the code above in your browser using DataLab