Returns the timestamp recorded when the change was committed.
Note that timestamps are set by the committing peer and may not be
accurate if the peer's clock is wrong.
Usage
am_change_time(change)
Value
A POSIXct timestamp
Arguments
change
An am_change object (from am_get_changes(),
am_get_changes(), or am_change_from_bytes())