Returns the current "heads" of the document - the hashes of the most recent
changes. These identify the current state of the document and can be used
for history operations.
Usage
am_get_heads(doc)
Value
A list of raw vectors, each containing a change hash. Usually there
is only one head, but after concurrent edits there may be multiple heads
until they are merged by a subsequent commit.