Learn R Programming

automerge (version 0.2.0)

am_get_last_local_change: Get the last change made by the local actor

Description

Returns the most recent change created by this document's actor. Useful for tracking local changes or implementing undo/redo functionality.

Usage

am_get_last_local_change(doc)

Value

A raw vector containing the serialized change, or NULL if no local changes have been made.

Arguments

doc

An Automerge document

Examples

Run this code
doc <- am_create()

# Initially, no local changes
am_get_last_local_change(doc)  # NULL

# Make a change
doc$key <- "value"
am_commit(doc, "Add key")

# Now we have a local change
change <- am_get_last_local_change(doc)
str(change)  # Raw vector

Run the code above in your browser using DataLab