powered by
Creates an R list with explicit Automerge list type. Use this when you need to create an empty list or force list type interpretation.
am_list(...)
A list with class am_list_type
am_list_type
Elements to include in the list
# Empty list (avoids ambiguity) am_list() # Populated list am_list("a", "b", "c")
Run the code above in your browser using DataLab